@@ -557,8 +557,8 @@ def main(wait_thread):
         if Connect_Error:
             if crypto_Error and passwd_flag:
                 wait_thread.stop()
-                sys.stdout.write('\r')
-                sys.stdout.flush()
+                # sys.stdout.write('\r')
+                # sys.stdout.flush()
                 print(_('Invalid password'))
                 # delete password from daemon list
                 clear_password(host, port)
